import { __decorate, __param } from 'tslib';
import { ElementRef, ChangeDetectorRef, Inject, Input, Component, Optional, NgModule } from '@angular/core';

class Icons {
    constructor(icons) {
        this.icons = icons;
    }
}

function uppercamelcase(str) {
    return str.toLowerCase().replace(/(?:^\w|[A-Z]|\b\w)/g, (firstLetter) => {
        return firstLetter.toUpperCase();
    }).replace(/[-_]/g, '');
}

let BoostrapIcons = class BoostrapIcons {
    constructor(elem, changeDetector, icons) {
        this.elem = elem;
        this.changeDetector = changeDetector;
        this.icons = icons;
    }
    ngOnChanges(changes) {
        // icons are provided as an array of objects because of "multi: true"
        const icons = Object.assign({}, ...this.icons);
        const svg = icons[uppercamelcase(changes.name.currentValue)] || '';
        if (!svg) {
            console.warn(`Icon not found: ${changes.name.currentValue}\n` +
                `Refer to documentation on https://github.com/biutas/ng-bootstrap-icons/issues`);
        }
        this.elem.nativeElement.innerHTML = svg;
        this.changeDetector.markForCheck();
    }
};
BoostrapIcons.ctorParameters = () => [
    { type: ElementRef },
    { type: ChangeDetectorRef },
    { type: Icons, decorators: [{ type: Inject, args: [Icons,] }] }
];
__decorate([
    Input()
], BoostrapIcons.prototype, "name", void 0);
BoostrapIcons = __decorate([
    Component({
        // tslint:disable-next-line:component-selector
        selector: 'bt-icon, bootstrap-icon',
        template: "<ng-content></ng-content>\r\n",
        styles: [":host{display:inline-block;width:24px;height:24px;fill:none;stroke:currentColor;stroke-width:2px;stroke-linecap:round;stroke-linejoin:round}"]
    }),
    __param(2, Inject(Icons))
], BoostrapIcons);

var BoostrapIconsModule_1;
let BoostrapIconsModule = BoostrapIconsModule_1 = class BoostrapIconsModule {
    constructor(icons) {
        this.icons = icons;
        if (!this.icons) {
            throw new Error(`No icon provided. Make sure to use 'BoostrapIconsModule.pick({ ... })' when importing the module\n` +
                `Refer to documentation on https://github.com/biutas/ng-bootstrap-icons/issues`);
        }
    }
    static pick(icons) {
        return {
            ngModule: BoostrapIconsModule_1,
            providers: [
                { provide: Icons, multi: true, useValue: icons }
            ]
        };
    }
};
BoostrapIconsModule.ctorParameters = () => [
    { type: Icons, decorators: [{ type: Optional }] }
];
BoostrapIconsModule = BoostrapIconsModule_1 = __decorate([
    NgModule({
        declarations: [
            BoostrapIcons
        ],
        exports: [
            BoostrapIcons
        ]
    }),
    __param(0, Optional())
], BoostrapIconsModule);

/**
 * Generated bundle index. Do not edit.
 */

export { BoostrapIconsModule, BoostrapIcons as ɵa, Icons as ɵb };
//# sourceMappingURL=ng-bootstrap-icons.js.map
